<?php
/**
 * ZyRed functions and definitions
 *
 * Sets up the theme and provides some helper functions. Some helper functions
 * are used in the theme as custom template tags. Others are attached to action and
 * filter hooks in WordPress to change core functionality.
 *
 * @package WordPress
 * @subpackage ZyRed
 * @since ZyRed 3.0
 */
 
 
/**
 * Set the content width based on the theme's design and stylesheet.
 */
if ( ! isset( $content_width ) )
	$content_width = 468;


add_action( 'after_setup_theme', 'zyred_setup' );

if ( ! function_exists( 'zyred_setup' ) ):
/**
 *
 * Sets up theme defaults and registers support for various WordPress features.
 *
 * @uses load_theme_textdomain() For translation/localization support.
 * @uses add_theme_support() To add support for post thumbnails, automatic feed links, and Post Formats.
 * @uses register_nav_menus() To add support for navigation menus.
 *
 * @since ZyRed 3.0
 */
function zyred_setup() {
	
	/* Make ZyRed available for translation.
	 * Translations can be added to the /languages/ directory.
	 */
	load_theme_textdomain( 'zyred', get_template_directory() . '/languages' );

	$locale = get_locale();
	$locale_file = get_template_directory() . "/languages/$locale.php";
	if ( is_readable( $locale_file ) )
		require_once( $locale_file );


	// Load widgets.
	require( dirname( __FILE__ ) . '/inc/widgets.php' );

	
	// Setup Theme Support Settings
	add_theme_support( 'automatic-feed-links');	
	
	// This theme uses wp_nav_menu() in one location.
	register_nav_menu('primary', __( 'Primary Navigation', 'zyred' ));	
}
endif;


/**
 * Register our sidebars and widgetized areas.
 *
 * @since ZyRed 3.0
 */
function zyred_widgets_init() {
	// Register Sidebars
	register_sidebar( array(
		'name' => __('Main Sidebar','zyred'),
		'id' => 'sidebar-1',
		'description' => __('Widgets in this area will be shown on the left-hand side.','zyred'),
		'before_widget' => '<li id="%1$s" class="widget %2$s">',
		'after_widget' => "</li>",
		'before_title' => '<h3 class="widget-title">',
		'after_title' => '</h3>',
	) );
	
	register_sidebar( array(
		'name' => __('Right Sidebar','zyred'),
		'id' => 'sidebar-2',
		'description' => __('Widgets in this area will be shown on the right-hand side.','zyred'),
		'before_widget' => '<li id="%1$s" class="widget %2$s">',
		'after_widget' => '</li>',
		'before_title' => '<h3 class="widget-title">',
		'after_title' => '</h3>',
	) );	
	
}
add_action( 'widgets_init', 'zyred_widgets_init' );

/**
 * Adjusts the comment_form() input types.
 *
 * @since ZyRed 3.0
 */
function zyred_fields($fields) {
	$commenter = wp_get_current_commenter();
	$req = get_option( 'require_name_email' );
	$fields =  array(
		'author' => '<p><input id="author" name="author" type="text" value="' . esc_attr( $commenter['comment_author'] ) . '" size="22" tabindex="1" /><label for="author"><small>' . __('Name','zyred') .  ( $req ? _e('(required)','zyred') : '' ) . '</small></label></p>',
		'email'  => '<p><input type="text" name="email" id="email" value="' . esc_attr(  $commenter['comment_author_email'] ) . '" size="22" tabindex="2" /><label for="email"><small>' . __('Mail (will not be published)','zyred') . ( $req ? _e('(required)','zyred') : '' ) . '</small></label></p>',
		'url'    => '<p><input type="text" name="url" id="url" value="' . esc_attr( $commenter['comment_author_url'] ) . '" size="22" tabindex="3" /><label for="url"><small>' . __('Website','zyred') . '</small></label></p>'
	);
	return $fields;
}
// ToDo: Use my custom comment fields
//add_filter('comment_form_default_fields','zyred_fields');

if ( ! function_exists( 'zyred_comment' ) ) :
/**
 * Template for comments and pingbacks.
 *
 * @since ZyRed 3.0
 */
function zyred_comment( $comment, $args, $depth ) {
	$GLOBALS['comment'] = $comment;
	switch ( $comment->comment_type ) :
		case 'pingback' :
		case 'trackback' :
	?>
	<li class="post pingback">
		<p><?php _e( 'Pingback:', 'zyred' ); ?> <?php comment_author_link(); ?><?php edit_comment_link( __( 'Edit', 'zyred' ), '<span class="edit-link">', '</span>' ); ?></p>
	<?php
			break;
		default :
	?>
	<li <?php comment_class(); ?> id="li-comment-<?php comment_ID(); ?>">

		<article id="comment-<?php comment_ID(); ?>" class="comment">
			
				<div style="height:60px;border-bottom: 1px solid #b0b0b0; padding-bottom: 5px;">
					<div class="gravatarside"><?php  echo get_avatar($comment,$size='48'); ?></div>
					<div style="float:left; margin: 0; padding: 0;">
						<br /><?php sprintf( '<span class="fn">%s</span>', comment_author_link() ) ?><br />
						<?php if ($comment->comment_approved == '0') : ?>
							<em class="comment-awaiting-moderation"><?php _e('Your comment is awaiting moderation.','zyred'); ?></em>
						<?php endif; ?>
						<a href="#comment-<?php comment_ID() ?>" title=""><?php comment_date(get_option( 'date_format' )) ?> <?php _e('at','zyred'); ?> <?php comment_time() ?></a> <?php edit_comment_link( __( 'Edit', 'zyred' ), '<span class="edit-link">', '</span>' ); ?>
					</div>
				</div>	




			<div class="comment-content"><?php comment_text(); ?></div>

			<div class="reply">
				<?php comment_reply_link( array_merge( $args, array( 'reply_text' => __( 'Reply', 'zyred' ), 'depth' => $depth, 'max_depth' => $args['max_depth'] ) ) ); ?>
			</div><!-- .reply -->
		</article><!-- #comment-## -->

	<?php
			break;
	endswitch;
}
endif; // ends check for zyred_comment()

/**
 * Get our wp_nav_menu() fallback, wp_page_menu(), to show a home link.
 */
function zyred_page_menu_args( $args ) {
	$args['show_home'] = true;
	return $args;
}
add_filter( 'wp_page_menu_args', 'zyred_page_menu_args' );
?>